package javax.swing.plaf.synth;

import java.beans.PropertyChangeEvent;
import java.awt.Graphics;
import javax.swing.JRootPane;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import javax.swing.plaf.basic.BasicRootPaneUI;

public class SynthRootPaneUI extends BasicRootPaneUI implements SynthUI
{
    private SynthStyle style;
    
    public SynthRootPaneUI() {
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new SynthRootPaneUI();
    }
    
    @Override
    protected void installDefaults(JRootPane rootPane) {
        this.updateStyle(rootPane);
    }
    
    @Override
    protected void uninstallDefaults(JRootPane rootPane) {
        SynthContext context = this.getContext(rootPane, 1);
        this.style.uninstallDefaults(context);
        context.dispose();
        this.style = null;
    }
    
    @Override
    public SynthContext getContext(JComponent component) {
        return this.getContext(component, this.getComponentState(component));
    }
    
    private SynthContext getContext(JComponent component, int n) {
        return SynthContext.getContext(component, this.style, n);
    }
    
    private int getComponentState(JComponent component) {
        return SynthLookAndFeel.getComponentState(component);
    }
    
    private void updateStyle(JComponent component) {
        SynthContext context = this.getContext(component, 1);
        SynthStyle style = this.style;
        this.style = SynthLookAndFeel.updateStyle(context, this);
        if (this.style != style && style != null) {
            this.uninstallKeyboardActions((JRootPane)component);
            this.installKeyboardActions((JRootPane)component);
        }
        context.dispose();
    }
    
    @Override
    public void update(Graphics graphics, JComponent component) {
        SynthContext context = this.getContext(component);
        SynthLookAndFeel.update(context, graphics);
        context.getPainter().paintRootPaneBackground(context, graphics, 0, 0, component.getWidth(), component.getHeight());
        this.paint(context, graphics);
        context.dispose();
    }
    
    @Override
    public void paint(Graphics graphics, JComponent component) {
        SynthContext context = this.getContext(component);
        this.paint(context, graphics);
        context.dispose();
    }
    
    protected void paint(SynthContext synthContext, Graphics graphics) {
    }
    
    @Override
    public void paintBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        synthContext.getPainter().paintRootPaneBorder(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void propertyChange(PropertyChangeEvent e) {
        if (SynthLookAndFeel.shouldUpdateStyle(e)) {
            this.updateStyle((JRootPane)e.getSource());
        }
        super.propertyChange(e);
    }
}
